==> libreoffice-still-sdk-24.8.7-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "Align", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#acaaef3a437193c979a93656446e56891", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#aa8fbab173f453f85590d3e10077ab4ef", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "ImagePosition", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a1d934a793957938d499d557e4fc6ad0a", null ],
    [ "ImageURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ae0d5ed0dbfdb5c4cbc19502b1814844e", null ],
    [ "Label", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a0999f1070ce4923004bfb388671f0387", null ],
    [ "MultiLine", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#afb440b6460d9580ab91a3fed3dd3670b", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "State", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a3e8bc4565e955c6dbdea9f3dc91f1b4f", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "VisualEffect", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a3b7a5be689a2abf51081cf43d2e92a13", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a002026db708f25e491f177b8f102f172", null ]
];

==> libreoffice-still-sdk-25.2.7-6-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "Align", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#acaaef3a437193c979a93656446e56891", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#aa8fbab173f453f85590d3e10077ab4ef", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "FontDescriptor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a9e110c55c0a3426a353ded5f029cd4e0", null ],
    [ "FontEmphasisMark", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac5c5781ab84a14cafec66b192fbdeae9", null ],
    [ "FontRelief", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac2b8dcc269c9ef6d27978db9b76caa43", null ],
    [ "Graphic", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ac9125eba7f4b60659a243b0f6d79f54b", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "ImagePosition", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a1d934a793957938d499d557e4fc6ad0a", null ],
    [ "ImageURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ae0d5ed0dbfdb5c4cbc19502b1814844e", null ],
    [ "Label", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a0999f1070ce4923004bfb388671f0387", null ],
    [ "MultiLine", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#afb440b6460d9580ab91a3fed3dd3670b", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "State", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a3e8bc4565e955c6dbdea9f3dc91f1b4f", null ],
    [ "Tabstop", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a58b62919451b71e65ecb718a57c053e5", null ],
    [ "TextColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a01c58818488ca5e1d235d71b625efa0e", null ],
    [ "TextLineColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a7de6f39eb42c328f77d4db6f6861bd6b", null ],
    [ "VerticalAlign", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#aeeee894b4f8f059ee92ccef71579845a", null ],
    [ "VisualEffect", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a3b7a5be689a2abf51081cf43d2e92a13", null ],
    [ "WritingMode", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlRadioButtonModel.html#a002026db708f25e491f177b8f102f172", null ]
];
